@@ -71,7 +71,6 @@ REMOTE_MODEL_MAP = {
 }
 GOOGLE_DRIVE_URL = "https://docs.google.com/uc?export=download"
 logger = logging.getLogger("ratsnlp")  # pylint: disable=invalid-name
-logger.setLevel(logging.INFO)
 
 
 def save_response_content(response, save_path):
@@ -211,6 +210,11 @@ def download_pretrained_model(args, config_only=False):
         raise ValueError(f"not valid model name({pretrained_model_name}), cannot download resources")
 
 
+def set_logger(args):
+    logger.setLevel(logging.INFO)
+    logger.info("Training/evaluation parameters %s", args)
+
+
 def load_arguments(argument_class, json_file_path=None):
     parser = HfArgumentParser(argument_class)
     if json_file_path is not None:
